/*
 * @(#)KeyOrCertificateEnumeration.java
 *
 * Cryptographic utilities
 * Developed at the Institute for Information Processing and Microprocessor Technology (FIM)
 * Johannes Kepler University Linz
 * Altenbergerstr. 69, A-4040 Linz, Austria
 */

package FIM.Util.Crypto;

import FIM.Util.FilterEnumeration;
import java.util.Vector;
import java.util.NoSuchElementException;
import java.security.KeyStore;
import java.security.KeyStoreException;

/**
An enumeration which returns only the names of key or certificate entries from a <code>KeyStore</code>.

@author Michael Sonntag
@version 1.0, 1.7.2000
@see java.security.KeyStore
*/
public class KeyOrCertificateEnumeration extends FilterEnumeration
{
    /** The store to enumerate */
    private KeyStore store=null;
    /** if <code>true</code> only key entried are returned, otherwise only certificate entries */
    private boolean keys=true;
    
    /**
    Creates a new enumeration returning only names for key or certificate entries from a key store.
    @param keys if <code>true</code> only key entried are returned, otherwise only certificate entries
    @param store the keystore to enumerate
    @throws KeyStoreException if the undelying enumeration of the keystore failed
    */
    public KeyOrCertificateEnumeration(boolean keys,KeyStore store) throws KeyStoreException
    {
        this.keys=keys;
        this.store=store;
        setBaseEnumeration(store.aliases());
    }
    
    /**
    The function implementing the filtering function.
    @param totest the object to test if it matches the filter
    @return <code>true</code> if the element should be returned; <code>false</code> if this
            element does not match the criteria and should be suppressed
    */
    protected boolean matchesFilter(Object toTest)
    {
        if(!(toTest instanceof String))
            throw new IllegalArgumentException("Can only filter obejcts of class 'String'");
        String test=(String)toTest;
        boolean res=false;
        try
        {
            res=(keys && store.isKeyEntry(test) || (!keys && store.isCertificateEntry(test)));
        }
        catch(KeyStoreException e)
        { 
            throw new NoSuchElementException("Error checking whether a key entry or not");
        }
        return res;
    }

}
