/*
 * @(#)CookieEnumeration.java
 *
 * Utility classes for managing cookies
 * Developed at the Institute for Information Processing and Microprocessor Technology (FIM)
 * Johannes Kepler University Linz
 * Altenbergerstr. 69, A-4040 Linz, Austria
 */

package FIM.Util.WWW.Cookies;

import FIM.Util.FilterEnumeration;
import java.util.Enumeration;

/**
An enumeration of cookies from a list matching a certain domain and/or path.

@author  Michael Sonntag
@version 1.0, 1.7.2000
@see FIM.Util.WWW.Cookies.Cookie
@see FIM.Util.WWW.Cookies.CookieStore
*/
public class CookieEnumeration extends FilterEnumeration
{
    /** The domain for filtering. */
    protected String domain=null;
    /** The path for filtering. */
    protected String path=null;

    /**
    Creates a new enumeration of matching cookies from a list.
    If a parameter is <code>null</code>, all cookies will match it.
    @param cookies the list of all cookies which will be filtered
    @param domain the domain the returned cookies are from (if <code>null</code> ignored)
    @param path the path the returned cookies are valid for (if <code>null</code> ignored)
    */
    public CookieEnumeration(Enumeration cookies,String domain,String path)
    {
        this.domain=domain;
        this.path=path;
        setBaseEnumeration(cookies);
    }

    /**
    The function implementing the filtering function.
    If path or domain is <code>null</code>, all cookies will match it.
    @param totest the object to test if it matches the filter
    @return <code>true</code> if the element should be returned; <code>false</code> if this
            element does not match the criteria and should be suppressed
    */
    protected boolean matchesFilter(Object toTest)
    {
        if(!(toTest instanceof Cookie))
            throw new IllegalArgumentException("Can only filter ocjects of class 'Cookie'");
        Cookie test=(Cookie)toTest;
        return (domain==null || test.matchDomain(domain)) && (path==null || test.matchPath(path));
    }

    /**
    Returns the next matching cookie from the store.
    @return the next matching cookie
    @throws NoSuchElementException if no more matching cookies exits
    */
    public Cookie nextCookie()
    {
        return (Cookie)nextElement();
    }

}
