/*
 * @(#)CookiePathComparator.java
 *
 * Utility classes for managing cookies
 * Developed at the Institute for Information Processing and Microprocessor Technology (FIM)
 * Johannes Kepler University Linz
 * Altenbergerstr. 69, A-4040 Linz, Austria
 */

package FIM.Util.WWW.Cookies;

import java.util.Comparator;

/**
Compares the paths of two cookies. Returns +1 if the path of the first cookie is less specific than
the path of the second cookie (e. g. "/" and "/bar") or -1 if the first path is more specific
than the second one (e. g. "/bar" and "/") .
<br><strong>NOTE: 0 is returned if the path is either the same or none of them is the start
of the other. It is therefore NOT consistent with <code>equal</code>!</strong>

@author Michael Sonntag
@version 1.0, 1.7.2000
*/
public class CookiePathComparator implements Comparator
{

    /**
    Creates a new comparator for cookie paths.
    */
    public CookiePathComparator()
    {
    }

    /**
    Compares its two arguments for order. Returns +1 if the path of the first cookie is less
    specific than the path of the second cookie (e. g. "/" and "/bar") or -1 if the first path
    is more specific than the second one (e. g. "/bar" and "/").
    <br><strong>NOTE: 0 is returned if the path is either the same or none of them is the start
    of the other. It is therefore NOT consistent with <code>equal</code>!</strong>
    @param o1 the first object to compare
    @param o2 the second object to compare
    @return a negative integer, zero, or a positive integer as the first argument is less than, equal to, or greater than the second
    @throws ClassCastException if the arguments' types are not both of class <code>Cookie</code>
    */
    public int compare(Object o1,Object o2)
    {
        int res=0;
        if(!(o1 instanceof Cookie) || !(o2 instanceof Cookie))
            throw new ClassCastException("Can only compare objects of class Cookie!");
        String path1=((Cookie)o1).getPath();
        String path2=((Cookie)o2).getPath();
        if(path1.startsWith(path2))
            res=-1;
        if(path2.startsWith(path1))
            res=+1;
        return res;
    }

}