/*
 * @(#)ButtonElement.java
 *
 * Classes for handling HTML-Forms without UI
 * Developed at the Institute for Information Processing and Microprocessor Technology (FIM)
 * Johannes Kepler University Linz
 * Altenbergerstr. 69, A-4040 Linz, Austria
 */

package FIM.Util.WWW.Form;

import javax.swing.text.html.HTMLDocument;
import javax.swing.text.Element;

/**
An element of a HTML-form of type BUTTON.

@author  Michael Sonntag
@version 1.0, 1.7.2000
*/
public abstract class ButtonElement extends ActionElement
{
    /**
    The type of this button.
    @serial
    */
    private String type=null;

    /**
    Creates a new BUTTON element.
    @param doc the document this element belongs to
    @param parent the parent of this element
    @param startOffs start offset of the element in the document
    @param endOffs end offset of the element in the document
    @param name the name of the element
    @param value the value of the element or <code>null</code> if none exists
    @param type the type of the button
    */
    public ButtonElement(HTMLDocument doc,Element parent,int startOffs,int endOffs,String name,String value,String type)
    {
        super(doc,parent,startOffs,endOffs,name,value);
        this.type=type;        
    }
    
    /**
    Retrieve the type of the button.
    @return type of the button
    */
    public String getType()
    {
        return type;
    }

    /**
    Returns a string representation of the button element.
    @return string representation of the form element
    */
    public String toString()
    {
        return "Button ("+getName()+":"+getValue()+")";
    }
}