/*
 * @(#)InputTextElement.java
 *
 * Classes for handling HTML-Forms without UI
 * Developed at the Institute for Information Processing and Microprocessor Technology (FIM)
 * Johannes Kepler University Linz
 * Altenbergerstr. 69, A-4040 Linz, Austria
 */

package FIM.Util.WWW.Form;

import javax.swing.text.html.HTMLDocument;
import javax.swing.text.Element;

/**
Class for the HTML element INPUT with subtype TEXT. It contains a single line of text with an optional maximum length.

@author  Michael Sonntag
@version 1.0, 1.7.2000
*/
public class InputTextElement extends TextElement
{
    /**
    The maximum length of the text string.
    @serial
    */
    private int maxLen=-1;

    /**
    Creates a new INPUT/TEXT element.
    @param doc the document this element belongs to
    @param parent the parent of this element
    @param startOffs start offset of the element in the document
    @param endOffs end offset of the element in the document
    @param name the name of the element
    @param initialText the initial text content of the element
    */
    public InputTextElement(HTMLDocument doc,Element parent,int startOffs,int endOffs,String name,String initialText)
    {
        super(doc,parent,startOffs,endOffs,name,initialText);
    }
    
    /**
    Set the text to a new value. If this text is longer than the length limit, it will be shortened.
    @param newText the new text to store
    */
    public void setText(String newText)
    {
        if(maxLen>=0 && newText.length()>maxLen)
            newText=newText.substring(0,maxLen);
        super.setText(newText);
    }
    
    /**
    Set the maximum length for the text. Negative values mean no limitation.
    If the current text is longer than the limit, it will be shortened.
    @param maxLen the new maximum length for the text
    */
    public void setMaxLen(int maxLen)
    {
        this.maxLen=maxLen;
        if(currentText.length()>maxLen)
            currentText=currentText.substring(0,maxLen);
    }
    
    /**
    Retrieve the current maximum length. -1 signals no limit.
    @return the current maximum length for the text
    */
    public int getMaxLen()
    {
        return maxLen;
    }

}