/*
 * @(#)ResetButtonElement.java
 *
 * Classes for handling HTML-Forms without UI
 * Developed at the Institute for Information Processing and Microprocessor Technology (FIM)
 * Johannes Kepler University Linz
 * Altenbergerstr. 69, A-4040 Linz, Austria
 */

package FIM.Util.WWW.Form;

import javax.swing.text.html.HTMLDocument;
import javax.swing.text.Element;

/**
A reset BUTTON.

@author  Michael Sonntag
@version 1.0, 1.7.2000
*/
public class ResetButtonElement extends ButtonElement
{
    /**
    Creates a new reset BUTTON element.
    @param doc the document this element belongs to
    @param parent the parent of this element
    @param startOffs start offset of the element in the document
    @param endOffs end offset of the element in the document
    @param name the name of the element
    @param value the value of the element or <code>null</code> if none exists
    */
    public ResetButtonElement(HTMLDocument doc,Element parent,int startOffs,int endOffs,String name,String value)
    {
        super(doc,parent,startOffs,endOffs,name,value,"Reset");
    }
    
    /**
    Resets the form this element belongs to.
    */
    public void doAction()
    {
        Element elem=getParentElement();
        while(elem!=null && !(elem instanceof HTMLForm))
            elem=elem.getParentElement();
        if(elem!=null)
            ((HTMLForm)elem).resetForm();
    }

    /**
    Returns a string representation of the reset button.
    @return string representation of the form element
    */
    public String toString()
    {
        return "Reset button ("+getName()+":"+getValue()+")";
    }
}