/*
 * @(#)SingleSelectionGroup.java
 *
 * Classes for handling HTML-Forms without UI
 * Developed at the Institute for Information Processing and Microprocessor Technology (FIM)
 * Johannes Kepler University Linz
 * Altenbergerstr. 69, A-4040 Linz, Austria
 */

package FIM.Util.WWW.Form;

import javax.swing.text.html.HTMLDocument;
import javax.swing.text.Element;

/**
A group of selectable elements, from which at every time only one can be selected.

@author  Michael Sonntag
@version 1.0, 1.7.2000
*/
public class SingleSelectionGroup extends ElementGroup 
{
    /**
    Create a new selection group, within which only one element can be selected at any time.
    @param doc the document this element belongs to
    @param parent the parent of this element
    @param name the name of the group
    */
    public SingleSelectionGroup(HTMLDocument doc,Element parent,String name)
    {
        super(doc,parent,name);
    }
    
    /**
    Select an element and deselect all others of the group.
    @param elem the element to select
    */
    public void selectElement(SelectableElement elem)
    {
        for(int i=0;i<getContainedElementCount();i++)
        {
            SelectableElement cur=(SelectableElement)getContainedElement(i);
            if(cur==elem)
                cur.selected=true;
            else
                cur.selected=false;
        }
    }

    /**
    Select the next element (used when deselecting). All others are deselected.
    @param elem the element, from which the next should be selected
    */
    public void selectNextElement(SelectableElement elem)
    {
        boolean selectNext=false;
        for(int i=0;i<getContainedElementCount();i++)
        {
            SelectableElement cur=(SelectableElement)getContainedElement(i);
            if(selectNext)
                cur.selected=true;
            else
                cur.selected=false;
            if(cur==elem)
                selectNext=true;
            else
                selectNext=false;
        }
        // If the last element was selected, select the first one
        if(selectNext)
            ((SelectableElement)getContainedElement(0)).selected=true;
    }

    /**
    Returns a string representation of the single selection group.
    @return string representation of the form element
    */
    public String toString()
    {
        String res="Single selection group with "+containedElems.size()+" elements.";
        for(int i=0;i<containedElems.size();i++)
            res+="\nElement "+i+": "+containedElems.elementAt(i).toString();
        return res;
    }
}