/*
 * @(#)SubmitButtonElement.java
 *
 * Classes for handling HTML-Forms without UI
 * Developed at the Institute for Information Processing and Microprocessor Technology (FIM)
 * Johannes Kepler University Linz
 * Altenbergerstr. 69, A-4040 Linz, Austria
 */

package FIM.Util.WWW.Form;

import javax.swing.text.html.HTMLDocument;
import javax.swing.text.Element;

/**
A submit BUTTON.

@author  Michael Sonntag
@version 1.0, 1.7.2000
*/
public class SubmitButtonElement extends ButtonElement
{
    /**
    The result of submitting the form:
    <ul>
    <li><code>null</code>: The page was not submitted through this element</li>
    <li><code>String</code>: The page returned from submitting</li>
    <li>Subclass of <code>IOException</code>: if an error occured during submitting</li>
    </ul>
    @serial
    */
    private Object result=null;

    /**
    Creates a new submit BUTTON element.
    @param doc the document this element belongs to
    @param parent the parent of this element
    @param startOffs start offset of the element in the document
    @param endOffs end offset of the element in the document
    @param name the name of the element
    @param value the value of the element or <code>null</code> if none exists
    */
    public SubmitButtonElement(HTMLDocument doc,Element parent,int startOffs,int endOffs,String name,String value)
    {
        super(doc,parent,startOffs,endOffs,name,value,"Submit");
    }
    
    /**
    Submits the form and stores the result.
    */
    public void doAction()
    {
        Element elem=getParentElement();
        while(elem!=null && !(elem instanceof HTMLForm))
            elem=elem.getParentElement();
        if(elem!=null)
        {
            try
            {
                result=((HTMLForm)elem).doSubmit(this);
            }
            catch(java.io.IOException e)
            { 
                result=e;
            }
        }
    }
    
    /**
    Fetch the result of submitting the form through this button.
    <br>Possible values:
    <ul>
    <li><code>null</code>: The page was not (yet) submitted through this element</li>
    <li><code>String</code>: The page returned from submitting</li>
    <li>Subclass of <code>IOException</code>: if an error occured during submitting</li>
    </ul>
    */
    public Object getResult()
    {
        return result;
    }

    /**
    Returns a string representation of the submit button.
    @return string representation of the form element
    */
    public String toString()
    {
        return "Submit button ("+getName()+":"+getValue()+")";
    }
}