/*
 * @(#)XMLEncodeable.java
 *
 * Miscellaneous XML utilities
 * Developed at the Institute for Information Processing and Microprocessor Technology (FIM)
 * Johannes Kepler University Linz
 * Altenbergerstr. 69, A-4040 Linz, Austria
 */

package FIM.Util.XML;

import java.io.Serializable;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
Represents a data element, which can be both serialized and retrieved encoded as an XML-element.
Deserialization is always possible, but for the XML-encoded form a special method has to be 
implemented, which recreates the data from en XML-element.
@author Michael Sonntag
@version 1.0
*/
public interface XMLEncodeable
{
    /** 
    Retrieve the data as a serializable.
    @return the data as a serializable
    */
	public Serializable getAsSerializable();
	
    /** 
    Retrieve the data as an XML element.
    @param doc the document within which to create the element
    @return the data as an element
    */
	public Element getAsXMLElement(Document doc);
	
    /** 
    Parse back the data from an XML element.
    @param elem the element containing the data to parse back
    @throws IllegalArgumentException if the element is incorrect (e. g. wrong tag name)
    */
	public void decodeXMLElement(Element elem) throws IllegalArgumentException;
	
	/**
	Retrieve a string representation of the object.
	@return a string representation of the data
	*/
    public String toString();
}
