/*
 * @(#)DataWrapper.java
 *
 * Classes for transferring value (a.k.a. money): Paying for things
 * Developed at the Institute for Information Processing and Microprocessor Technology (FIM)
 * Johannes Kepler University Linz
 * Altenbergerstr. 69, A-4040 Linz, Austria
 */

package FIM.payment;

import java.security.cert.Certificate;
import java.io.Serializable;

/**
A wrapper for the data in <code>DataPayment</code>. The data can be either a string, an array of bytes or a serializable object.
The type is decided in the constructor. Also contains a characteristic (description of the data) and its value. For easier usage,
a flag is contained to mark it whether it has been sued for payment or not.
@author Michael Sonntag
@version 1.0
@see FIM.payment.DataPayment
*/
public class DataWrapper implements Serializable
{
    /** The value of the data. */
    public Price value=null;
    /** The characteristic (=description) of the data. */
    public String characteristic=null;

    /** The actual data: Type string. */
    public String stringData=null;
    /** The actual data: Type array of bytes. */
    public byte[] byteData=null;
    /** The actual data: Type serializable object. */
    public Serializable serialData=null;

    /** Flag to mark whether this data has already been used for payment or not. */
    public boolean used=false;

    /**
    Create a new data wrapper with the type string.
    @param characteristic the description of the content
    @param value the value of the data
    @param stringData the string data
    */
    public DataWrapper(String characteristic,String stringData,Price value)
    {
        this.characteristic=characteristic;
        this.stringData=stringData;
        this.value=value;
    }

    /**
    Create a new data wrapper with the type array of bytes.
    @param characteristic the description of the content
    @param value the value of the data
    @param byteData the byte data
    */
    public DataWrapper(String characteristic,byte[] byteData,Price value)
    {
        this.characteristic=characteristic;
        this.byteData=byteData;
        this.value=value;
    }

    /**
    Create a new data wrapper with the type serializable object.
    @param characteristic the description of the content
    @param value the value of the data
    @param serialData the object data
    */
    public DataWrapper(String characteristic,Serializable serialData,Price value)
    {
        this.characteristic=characteristic;
        this.serialData=serialData;
        this.value=value;
    }

}