/*
 * @(#)EmptyPayment.java
 *
 * Classes for transferring value (a.k.a. money): Paying for things
 * Developed at the Institute for Information Processing and Microprocessor Technology (FIM)
 * Johannes Kepler University Linz
 * Altenbergerstr. 69, A-4040 Linz, Austria
 */

package FIM.payment;

import java.util.Date;
import java.util.Calendar;
import java.io.*;
import FIM.Util.XML.XMLEncodeable;
import FIM.Util.XML.XMLUtils;

import java.security.cert.Certificate;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.Signature;
import java.security.NoSuchAlgorithmException;
import java.security.InvalidKeyException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateFactory;
import java.security.NoSuchProviderException;
import java.security.SignatureException;
import java.text.DateFormat;

import org.xml.sax.SAXException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

/*
// Needed for testing; see main at end
import org.apache.xalan.serialize.Serializer;
import org.apache.xalan.serialize.SerializerFactory;
import org.apache.xalan.templates.OutputProperties;
import javax.xml.parsers.DocumentBuilderFactory;  
import javax.xml.parsers.DocumentBuilder;  
import PkgAgentSystem.Crypto.*;
*/


/**
A class representing the payment by providign some nothing. To be used for free "purchases".
The characteristic is "NO PAYMENT".
@author Michael Sonntag
@version 1.0
@see FIM.payment.Invoice
*/
public class EmptyPayment extends PaymentBase
{
    /**
    Create a new empty object. To be used for parsing in XML data later. Must be public so it can be
    created by factory methods.
    */
    public EmptyPayment()
    {
    }

    /**
    Create a new empty payment.
    @param invoice the invoice this payment is for
    */
    public EmptyPayment(Invoice inv)
    {
        super(inv,"NO PAYMENT");
    }

    /**
    Create a new empty payment from an XML element.
    @param elem the XML element containing the encoded form
    */
    public EmptyPayment(Element elem)
    {
        decodeXMLElement(elem);
    }

    /**
    Retrieve the payment as an XML element.
    @param doc the document within which to create the element
    @return the currency as an element
    */
	public Element getAsXMLElement(Document doc)
	{
	    Element el=doc.createElement("NoPayment");
	    el.appendChild(super.getAsXMLElement(doc));
	    return el;
	}

    /**
    Parse back the payment from an XML element.
    @param elem the element containing the currency to parse back
    @throws IllegalArgumentException if the element is incorrect (e. g. wrong tag name)
    */
	public void decodeXMLElement(Element elem) throws IllegalArgumentException
	{
	    super.decodeXMLElement((Element)elem.getFirstChild());
	}

}