/*
 * @(#)VoucherWrapper.java
 *
 * Classes for transferring value (a.k.a. money): Paying for things
 * Developed at the Institute for Information Processing and Microprocessor Technology (FIM)
 * Johannes Kepler University Linz
 * Altenbergerstr. 69, A-4040 Linz, Austria
 */

package FIM.payment;

import java.security.cert.Certificate;

/**
A wrapper for the voucher in <code>VoucherPayment</code>. The data must be a certificate.
Also contains a characteristic (description of the voucher) and its value. For easier usage,
a flag is contained to mark it whether it has been sued for payment or not.
@author Michael Sonntag
@version 1.0
*/
public class VoucherWrapper implements java.io.Serializable
{
    /** The value of the voucher. */
    public Price value=null;
    /** The characteristic (=description) of the voucher. */
    public String characteristic=null;
    /** The voucher itself. */
    public Certificate voucher=null;
    /** Flag to mark whether this data has already been used for payment or not. */
    public boolean used=false;

    /**
    Create a new voucher wrapper.
    @param characteristic the description of the voucher
    @param value the value of the voucher
    @param voucher the voucher itself
    */
    public VoucherWrapper(String characteristic,Certificate voucher,Price value)
    {
        this.characteristic=characteristic;
        this.voucher=voucher;
        this.value=value;
    }

}