/*
 * @(#)CreateCertificates.java
 *
 * Classes for testing
 * Developed at the Institute for Information Processing and Microprocessor Technology (FIM)
 * Johannes Kepler University Linz
 * Altenbergerstr. 69, A-4040 Linz, Austria
 */

package FIM.test;

import java.io.*;
import java.security.*;
import java.security.cert.*;
import java.util.*;
import iaik.asn1.structures.*;
import iaik.asn1.*;
import iaik.x509.*;
import javax.crypto.SecretKey;
import javax.crypto.KeyGenerator;
import java.math.BigInteger;
import java.security.spec.*;

import PkgAgentSystem.Crypto.PersonalSecurityStoreFactory;
import PkgAgentSystem.Crypto.PersonalSecurityStore;
import FIM.Util.Crypto.NamedKeyAndCertificate;

/**
Creates some certificates useable for testing and stores them in files (certificate PLUS secret key).
<strong>Should be used for testing ONLY!</strong>
<ul>
<li>A Certificate Authroity (CA) certificate (DSA), stored in "ca_certificate.DSA"
<li>A certificate signed with the CA certificate (DSA), stored in  "certificate_CAsigned.DSA"
<li>A certificate signed by itself (DSA), stored in "certificate_selfsigned.DSA"
</ul>
All certificates are valid for one year.
One parameter required, the directory where the files will be placed.
<br>Requires IAIK security provider!
@author  Michael Sonntag
@version 1.0, 1.7.2000
*/
public class CreateCertificates
{

    public static void main(String[] args)
    {
        if(args.length!=1)
        {
            System.out.println("Usage: java FIM.test.CreateCertificates outputDirectory\n");
            System.exit(1);
        }
        String outDir=args[0];
        Name issuer;
        Name subject;
        GregorianCalendar cal;
//        java.security.cert.Certificate[] certs=new java.security.cert.Certificate[1];
	    try
	    {
	        System.out.println("Creating CA DSA key ...");
	        KeyPairGenerator keyGen=KeyPairGenerator.getInstance("DSA");
    	    keyGen.initialize(1024);
	        KeyPair kp=keyGen.genKeyPair();
    		PrivateKey ca_dsa_privKey=kp.getPrivate();
	    	PublicKey dsa_pubKey=kp.getPublic();
	        System.out.println("CA-DSA key generated");
    	   	System.out.println("Creating CA-DSA certificate...");
            iaik.x509.X509Certificate cert = new iaik.x509.X509Certificate();
    	    issuer = new Name();
    		issuer.addRDN(ObjectID.country, "AT");
          	issuer.addRDN(ObjectID.organization ,"Uni-Linz");
      	    issuer.addRDN(ObjectID.organizationalUnit ,"FIM");
          	issuer.addRDN(ObjectID.commonName ,"FIM Test CA, DSA, self-signed");
          	cert.setIssuerDN(issuer);
          	cert.setSubjectDN(issuer);
	   	    cert.setPublicKey(dsa_pubKey);
    	   	cert.setSerialNumber(new BigInteger("1"));
	       	cal=new GregorianCalendar();
	   	    cert.setValidNotBefore(cal.getTime());
    	   	cal.add(java.util.Calendar.YEAR,1);
	       	cert.setValidNotAfter(cal.getTime());
		    System.out.println("Signing CA-DSA certificate...");
    		cert.sign(iaik.asn1.structures.AlgorithmID.dsa,ca_dsa_privKey);
	    	System.out.println("Storing CA-DSA keys and certificate...");
	       	FileOutputStream os=new FileOutputStream(outDir+"\\ca_certificate.DSA");
	       	ObjectOutputStream out=new ObjectOutputStream(os);
    		out.writeObject(ca_dsa_privKey.getAlgorithm());
	    	KeyFactory keyFactory=KeyFactory.getInstance(ca_dsa_privKey.getAlgorithm());
		    PKCS8EncodedKeySpec spec=(PKCS8EncodedKeySpec)keyFactory.getKeySpec(ca_dsa_privKey,PKCS8EncodedKeySpec.class);
	    	byte[] buf=spec.getEncoded();
		    out.writeObject(buf);
	       	out.write(cert.getEncoded());
    	   	out.close();
    	   	// Create normal (trusted) certificate
	        System.out.println("Creating Trusted DSA key ...");
	        keyGen=KeyPairGenerator.getInstance("DSA");
    	    keyGen.initialize(1024);
	        kp=keyGen.genKeyPair();
    		PrivateKey dsa_privKey=kp.getPrivate();
	    	dsa_pubKey=kp.getPublic();
	        System.out.println("Trusted DSA key generated");
    	   	System.out.println("Creating Trusted DSA certificate...");
            cert = new iaik.x509.X509Certificate();
          	cert.setIssuerDN(issuer);  // Test CA from above
		    subject = new Name();
    		subject.addRDN(ObjectID.country, "AT");
          	subject.addRDN(ObjectID.organization ,"Uni-Linz");
      	    subject.addRDN(ObjectID.organizationalUnit ,"FIM");
          	subject.addRDN(ObjectID.commonName ,"Tester, DSA (CA-signed)");
          	cert.setSubjectDN(subject);
	   	    cert.setPublicKey(dsa_pubKey);
    	   	cert.setSerialNumber(new BigInteger("1"));
	       	cal=new GregorianCalendar();
	   	    cert.setValidNotBefore(cal.getTime());
    	   	cal.add(java.util.Calendar.YEAR,1);
	       	cert.setValidNotAfter(cal.getTime());
		    System.out.println("Signing Trusted DSA certificate...");
    		cert.sign(iaik.asn1.structures.AlgorithmID.dsa,ca_dsa_privKey);
	    	System.out.println("Storing Trusted DSA keys and certificate...");
	       	os=new FileOutputStream(outDir+"\\certificate_CAsigned.DSA");
	       	out=new ObjectOutputStream(os);
    		out.writeObject(dsa_privKey.getAlgorithm());
	    	keyFactory=KeyFactory.getInstance(dsa_privKey.getAlgorithm());
		    spec=(PKCS8EncodedKeySpec)keyFactory.getKeySpec(dsa_privKey,PKCS8EncodedKeySpec.class);
	    	buf=spec.getEncoded();
		    out.writeObject(buf);
	       	out.write(cert.getEncoded());
    	   	out.close();
    	   	// Create normal (UNtrusted) certificate
	        System.out.println("Creating Untrusted DSA key ...");
	        keyGen=KeyPairGenerator.getInstance("DSA");
    	    keyGen.initialize(1024);
	        kp=keyGen.genKeyPair();
    		dsa_privKey=kp.getPrivate();
	    	dsa_pubKey=kp.getPublic();
	        System.out.println("Untrusted DSA key generated");
    	   	System.out.println("Creating Untrusted DSA certificate...");
            cert = new iaik.x509.X509Certificate();
		    issuer=new Name();
    		issuer.addRDN(ObjectID.country, "AT");
          	issuer.addRDN(ObjectID.organization ,"Uni-Linz");
      	    issuer.addRDN(ObjectID.organizationalUnit ,"FIM");
          	issuer.addRDN(ObjectID.commonName ,"Tester, DSA (self-signed)");
          	cert.setIssuerDN(issuer);
          	cert.setSubjectDN(issuer);
	   	    cert.setPublicKey(dsa_pubKey);
    	   	cert.setSerialNumber(new BigInteger("1"));
	       	cal=new GregorianCalendar();
	   	    cert.setValidNotBefore(cal.getTime());
    	   	cal.add(java.util.Calendar.YEAR,1);
	       	cert.setValidNotAfter(cal.getTime());
		    System.out.println("Signing Untrusted DSA certificate...");
    		cert.sign(iaik.asn1.structures.AlgorithmID.dsa,dsa_privKey);
	    	System.out.println("Storing Untrusted DSA keys and certificate...");
	       	os=new FileOutputStream(outDir+"\\certificate_selfsigned.DSA");
	       	out=new ObjectOutputStream(os);
    		out.writeObject(dsa_privKey.getAlgorithm());
	    	keyFactory=KeyFactory.getInstance(dsa_privKey.getAlgorithm());
		    spec=(PKCS8EncodedKeySpec)keyFactory.getKeySpec(dsa_privKey,PKCS8EncodedKeySpec.class);
	    	buf=spec.getEncoded();
		    out.writeObject(buf);
	       	out.write(cert.getEncoded());
    	   	out.close();
/*    	   	
   		    PersonalSecurityStore store=PersonalSecurityStoreFactory.createPersonalSecurityStore();
	        System.out.println("Creating RSA key ...");
	        keyGen=KeyPairGenerator.getInstance("RSA");
    	    keyGen.initialize(1024);
	        kp=keyGen.genKeyPair();
    		PrivateKey rsa_privKey=kp.getPrivate();
	    	PublicKey rsa_pubKey=kp.getPublic();
	        System.out.println("RSA key generated");
    	   	System.out.println("Creating RSA server certificate...");
            cert = new iaik.x509.X509Certificate();
    	    issuer = new Name();
    		issuer.addRDN(ObjectID.country, "AT");
          	issuer.addRDN(ObjectID.organization ,"Uni-Linz");
      	    issuer.addRDN(ObjectID.organizationalUnit ,"FIM");
          	issuer.addRDN(ObjectID.commonName ,"FIM Test CA");
          	cert.setIssuerDN(issuer);
		    subject = new Name();
    		subject.addRDN(ObjectID.country, "AT");
          	subject.addRDN(ObjectID.organization ,"Uni-Linz");
      	    subject.addRDN(ObjectID.organizationalUnit ,"FIM");
          	subject.addRDN(ObjectID.commonName ,"Server Certificate, RSA (self-signed)");
          	cert.setSubjectDN(subject);
	   	    cert.setPublicKey(rsa_pubKey);
    	   	cert.setSerialNumber(new BigInteger("1"));
	       	cal=new GregorianCalendar();
	   	    cert.setValidNotBefore(cal.getTime());
    	   	cal.add(java.util.Calendar.YEAR,1);
	       	cert.setValidNotAfter(cal.getTime());
		    System.out.println("Signing RSA certificate...");
    		cert.sign(iaik.asn1.structures.AlgorithmID.md5WithRSAEncryption,rsa_privKey);
	    	System.out.println("Storing RSA keys and certificate...");
    	   	store.addOwnerPrivateKeyAndCertificate(new NamedKeyAndCertificate("Server Certificate",rsa_privKey,cert));
    	   	store.writePersonalSecurityStore("SecurityStore.store","password".toCharArray());
	        System.out.println("Creating trusted RSA key ...");
	        keyGen=KeyPairGenerator.getInstance("RSA");
    	    keyGen.initialize(1024);
	        kp=keyGen.genKeyPair();
    		rsa_privKey=kp.getPrivate();
	    	rsa_pubKey=kp.getPublic();
	        System.out.println("Trusted RSA key generated");
    	   	System.out.println("Creating trusted RSA certificate...");
            cert = new iaik.x509.X509Certificate();
    	    issuer = new Name();
    		issuer.addRDN(ObjectID.country, "AT");
          	issuer.addRDN(ObjectID.organization ,"Uni-Linz");
      	    issuer.addRDN(ObjectID.organizationalUnit ,"FIM");
          	issuer.addRDN(ObjectID.commonName ,"FIM Test CA");
          	cert.setIssuerDN(issuer);
		    subject = new Name();
    		subject.addRDN(ObjectID.country, "AT");
          	subject.addRDN(ObjectID.organization ,"Uni-Linz");
      	    subject.addRDN(ObjectID.organizationalUnit ,"FIM");
          	subject.addRDN(ObjectID.commonName ,"Trusted Certificate, RSA (DSA-CA signed)");
          	cert.setSubjectDN(subject);
	   	    cert.setPublicKey(rsa_pubKey);
    	   	cert.setSerialNumber(new BigInteger("2"));
	       	cal=new GregorianCalendar();
	   	    cert.setValidNotBefore(cal.getTime());
    	   	cal.add(java.util.Calendar.YEAR,1);
	       	cert.setValidNotAfter(cal.getTime());
		    System.out.println("Signing trusted RSA certificate...");
    		cert.sign(iaik.asn1.structures.AlgorithmID.dsa,ca_dsa_privKey);
	    	System.out.println("Storing trusted RSA keys and certificate...");
    	   	store.addOwnerPrivateKeyAndCertificate(new NamedKeyAndCertificate("Trusted RSA Certificate",rsa_privKey,cert));
    	   	store.writePersonalSecurityStore("SecurityStore.store","password".toCharArray());
	       	os=new FileOutputStream("certificate_CAsigned.RSA");
	       	out=new ObjectOutputStream(os);
    		out.writeObject(rsa_privKey.getAlgorithm());
	    	keyFactory=KeyFactory.getInstance(rsa_privKey.getAlgorithm());
		    spec=(PKCS8EncodedKeySpec)keyFactory.getKeySpec(rsa_privKey,PKCS8EncodedKeySpec.class);
	    	buf=spec.getEncoded();
		    out.writeObject(buf);
	       	out.write(cert.getEncoded());
    	   	out.close();
*/    	   	
        }
        catch(CertificateException e)
        {
        	System.out.println("Error while creating certificates: "+e.toString());
        	System.exit(1);
        }
        catch(NoSuchAlgorithmException e)
        {
            System.err.println("Couldn't create keystore: Cryptographic algorithm not found. Please check configuration of JRE! ("+e.toString()+")");
        	System.exit(1);
        }
        catch(InvalidKeySpecException e)
        {
        	System.out.println("Internal cryptographic error while buildng keystore: "+e.toString());
        	System.exit(1);
        }
        catch(InvalidKeyException e)
        {
        	System.out.println("Internal cryptographic error while buildng keystore: "+e.toString());
        	System.exit(1);
        }
        catch(FileNotFoundException e)
        {
        	System.out.println("Couldn't open keystore file: "+e.toString());
        	System.exit(1);
        }
/*        
        catch(KeyStoreException e)
        {
        	System.out.println("Couldn't store Server certificate: "+e.toString());
        	System.exit(1);
        }
*/        
        catch(Exception e)
        {
        	System.out.println("Couldn't open/read/write keystore file: "+e.toString());
        	System.exit(1);
        }
        System.out.println("Completed");
    }
}