/*
 * @(#)FilterTest.java
 *
 * Testing classes for FIM utility classes
 * Developed at the Institute for Information Processing and Microprocessor Technology (FIM)
 * Johannes Kepler University Linz
 * Altenbergerstr. 69, A-4040 Linz, Austria
 */

package FIM.test;

import java.util.Enumeration;
import FIM.Util.FilterEnumeration;
import java.util.Iterator;
import FIM.Util.FilterIterator;
import java.util.NoSuchElementException;

/**
Class for testing the classes <code>FilterEnumeration</code> and <code>FilterIterator</code>
in package <code>FIM.Util</code>. Should be a complete test.

@author  Michael Sonntag
@version 1.0, 1.7.2000
*/
public class FilterTest
{
    /**
    Print an error message and terminate the program with an return code of 1.
    @param msg the message to print
    */
    private static void fail(String msg)
    {
        System.out.println(msg);
        System.exit(1);
    }   

    /**
    Test the class <code>FIM.Util.FilterIterator</code>.
    */
    public static void IteratorTest()
    {
        int successful=0;
        System.out.println("Testing FilterIterator...\n");
        java.util.Vector v;
        FilterIteratorTestIter iter;
        System.out.println("Test 1: No elements");
        v=new java.util.Vector();
        iter=new FilterIteratorTestIter(v.iterator());
        if(iter.hasNext())
            fail("Test 1 failed (hasNext)");
        try
        {
            iter.next();
            fail("Test 1 failed (next)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 2: Only non-matching elements");
        v=new java.util.Vector();
        v.add(new Integer(-1));
        v.add(new Integer(-2));
        v.add(new Integer(-3));
        iter=new FilterIteratorTestIter(v.iterator());
        if(iter.hasNext())
            fail("Test 2 failed (hasNext)");
        try
        {
            iter.next();
            fail("Test 2 failed (next)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        iter=new FilterIteratorTestIter(v.iterator());
        try
        {
            iter.next();
            fail("Test 2 failed (next)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        if(iter.hasNext())
            fail("Test 2 failed (hasNext)");
        System.out.println("Test 3: One non-matching elements");
        v=new java.util.Vector();
        v.add(new Integer(-1));
        iter=new FilterIteratorTestIter(v.iterator());
        if(iter.hasNext())
            fail("Test 3 failed (hasNext)");
        try
        {
            iter.next();
            fail("Test 3 failed (next)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 4: Only matching elements");
        v=new java.util.Vector();
        v.add(new Integer(1));
        v.add(new Integer(2));
        v.add(new Integer(3));
        iter=new FilterIteratorTestIter(v.iterator());
        if(!iter.hasNext())
            fail("Test 4 failed (hasNext)");
        try
        {
            if(((Integer)iter.next()).intValue()!=1)
                fail("Test 4 failed (wrong element 1)");
            if(!iter.hasNext())
                fail("Test 4 failed (hasNext)");
            if(((Integer)iter.next()).intValue()!=2)
                fail("Test 4 failed (wrong element 2)");
            if(!iter.hasNext())
                fail("Test 4 failed (hasNext)");
            if(((Integer)iter.next()).intValue()!=3)
                fail("Test 4 failed (wrong element 3)");
        }
        catch(Exception e)
        {
            System.out.println("Test 4 failed (next)");
            System.exit(1);
        }
        if(iter.hasNext())
            fail("Test 4 failed (hasNext)");
        try
        {
            iter.next();
            fail("Test 4 failed (next)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 5: One matching elements");
        v=new java.util.Vector();
        v.add(new Integer(1));
        iter=new FilterIteratorTestIter(v.iterator());
        if(!iter.hasNext())
            fail("Test 5 failed (hasNext)");
        try
        {
            if(((Integer)iter.next()).intValue()!=1)
                fail("Test 5 failed (wrong element)");
        }
        catch(Exception e)
        {
            System.out.println("Test 5 failed (next)");
            System.exit(1);
        }
        if(iter.hasNext())
            fail("Test 5 failed (hasNext)");
        try
        {
            iter.next();
            fail("Test 5 failed (next)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 6: First element matching");
        v=new java.util.Vector();
        v.add(new Integer(1));
        v.add(new Integer(-2));
        v.add(new Integer(-3));
        iter=new FilterIteratorTestIter(v.iterator());
        if(!iter.hasNext())
            fail("Test 6 failed (hasNext)");
        try
        {
            if(((Integer)iter.next()).intValue()!=1)
                fail("Test 6 failed (wrong element)");
        }
        catch(Exception e)
        {
            System.out.println("Test 6 failed (next)");
            System.exit(1);
        }
        if(iter.hasNext())
            fail("Test 6 failed (hasNext)");
        try
        {
            iter.next();
            fail("Test 6 failed (next)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 7: Middle element matching");
        v=new java.util.Vector();
        v.add(new Integer(-1));
        v.add(new Integer(2));
        v.add(new Integer(-3));
        iter=new FilterIteratorTestIter(v.iterator());
        if(!iter.hasNext())
            fail("Test 7 failed (hasNext)");
        try
        {
            if(((Integer)iter.next()).intValue()!=2)
                fail("Test 7 failed (wrong element)");
        }
        catch(Exception e)
        {
            System.out.println("Test 7 failed (next)");
            System.exit(1);
        }
        if(iter.hasNext())
            fail("Test 7 failed (hasNext)");
        try
        {
            iter.next();
            fail("Test 7 failed (next)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 8: Last element matching");
        v=new java.util.Vector();
        v.add(new Integer(-1));
        v.add(new Integer(-2));
        v.add(new Integer(3));
        iter=new FilterIteratorTestIter(v.iterator());
        if(!iter.hasNext())
            fail("Test 8 failed (hasNext)");
        try
        {
            if(((Integer)iter.next()).intValue()!=3)
                fail("Test 8 failed (wrong element)");
        }
        catch(Exception e)
        {
            System.out.println("Test 8 failed (next)");
            System.exit(1);
        }
        if(iter.hasNext())
            fail("Test 8 failed (hasNext)");
        try
        {
            iter.next();
            fail("Test 8 failed (next)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 9: First element not matching");
        v=new java.util.Vector();
        v.add(new Integer(-1));
        v.add(new Integer(2));
        v.add(new Integer(3));
        iter=new FilterIteratorTestIter(v.iterator());
        if(!iter.hasNext())
            fail("Test 9 failed (hasNext)");
        try
        {
            if(((Integer)iter.next()).intValue()!=2)
                fail("Test 9 failed (wrong element)");
            if(!iter.hasNext())
                fail("Test 9 failed (hasNext)");
            if(((Integer)iter.next()).intValue()!=3)
                fail("Test 9 failed (wrong element)");
        }
        catch(Exception e)
        {
            System.out.println("Test 9 failed (next)");
            System.exit(1);
        }
        if(iter.hasNext())
            fail("Test 9 failed (hasNext)");
        try
        {
            iter.next();
            fail("Test 9 failed (next)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 10: Middle element not matching");
        v=new java.util.Vector();
        v.add(new Integer(1));
        v.add(new Integer(-2));
        v.add(new Integer(3));
        iter=new FilterIteratorTestIter(v.iterator());
        if(!iter.hasNext())
            fail("Test 10 failed (hasNext)");
        try
        {
            if(((Integer)iter.next()).intValue()!=1)
                fail("Test 10 failed (wrong element)");
            if(!iter.hasNext())
                fail("Test 10 failed (hasNext)");
            if(((Integer)iter.next()).intValue()!=3)
                fail("Test 10 failed (wrong element)");
        }
        catch(Exception e)
        {
            System.out.println("Test 10 failed (next)");
            System.exit(1);
        }
        if(iter.hasNext())
            fail("Test 10 failed (hasNext)");
        try
        {
            iter.next();
            fail("Test 10 failed (next)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 11: Last element not matching");
        v=new java.util.Vector();
        v.add(new Integer(1));
        v.add(new Integer(2));
        v.add(new Integer(-3));
        iter=new FilterIteratorTestIter(v.iterator());
        if(!iter.hasNext())
            fail("Test 11 failed (hasNext)");
        try
        {
            if(((Integer)iter.next()).intValue()!=1)
                fail("Test 11 failed (wrong element)");
            if(!iter.hasNext())
                fail("Test 11 failed (hasNext)");
            if(((Integer)iter.next()).intValue()!=2)
                fail("Test 11 failed (wrong element)");
        }
        catch(Exception e)
        {
            System.out.println("Test 11 failed (next)");
            System.exit(1);
        }
        if(iter.hasNext())
            fail("Test 11 failed (hasNext)");
        try
        {
            iter.next();
            fail("Test 11 failed (next)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 12: Setting base iterator twice");
        v=new java.util.Vector();
        v.add(new Integer(1));
        iter=new FilterIteratorTestIter(v.iterator());
        try
        {
            iter.setBaseIterator(v.iterator());
            fail("Test 12 failed (base numeration set twice)");
        }
        catch(IllegalStateException e)
        {
            successful++;
        }
        System.out.println("Test 13: Base iterator not set");
        v=new java.util.Vector();
        v.add(new Integer(1));
        iter=new FilterIteratorTestIter(null);
        try
        {
            iter.next();
            fail("Test 13 failed (base iterator not set)");
        }
        catch(IllegalStateException e)
        {
            successful++;
        }
        try
        {
            iter.hasNext();
            fail("Test 13 failed (base iterator not set)");
        }
        catch(IllegalStateException e)
        {
            successful++;
        }
        System.out.println("Test 14: Removing from empty list");
        v=new java.util.Vector();
        iter=new FilterIteratorTestIter(v.iterator());
        try
        {
            iter.remove();
            fail("Test 14 failed (remove from empty list)");
        }
        catch(IllegalStateException e)
        {
            successful++;
        }
        System.out.println("Test 15: Removing only element");
        v=new java.util.Vector();
        v.add(new Integer(1));
        iter=new FilterIteratorTestIter(v.iterator());
        try
        {
            iter.remove();
            fail("Test 15 failed (removing only element)");
        }
        catch(IllegalStateException e)
        {
            successful++;
        }
        iter.next();
        iter.remove();
        if(v.size()!=0)
            fail("Test 15 failed (element not removed)");
        try
        {
            iter.remove();
            fail("Test 15 failed (double removal)");
        }
        catch(IllegalStateException e)
        {
            successful++;
        }
        System.out.println("Test 16: Removing first element");
        v=new java.util.Vector();
        v.add(new Integer(1));
        v.add(new Integer(2));
        iter=new FilterIteratorTestIter(v.iterator());
        try
        {
            iter.remove();
            fail("Test 16 failed (remove first element)");
        }
        catch(IllegalStateException e)
        {
            successful++;
        }
        iter.next();
        iter.remove();
        if(v.size()!=1)
            fail("Test 16 failed (element not removed)");
        if(!iter.hasNext())
            fail("Test 16 failed (hasNext)");
        try
        {
            if(((Integer)iter.next()).intValue()!=2)
                fail("Test 16 failed (wrong element)");
        }
        catch(IllegalStateException e)
        {
              successful++;
      }
        System.out.println("Test 17: Removing middle element");
        v=new java.util.Vector();
        v.add(new Integer(1));
        v.add(new Integer(2));
        v.add(new Integer(3));
        iter=new FilterIteratorTestIter(v.iterator());
        iter.next();
        iter.next();
        iter.remove();
        if(v.size()!=2)
            fail("Test 17 failed (element not removed)");
        if(!iter.hasNext())
            fail("Test 17 failed (hasNext)");
        try
        {
            if(((Integer)iter.next()).intValue()!=3)
                fail("Test 17 failed (wrong element)");
        }
        catch(IllegalStateException e)
        {
               successful++;
     }
        System.out.println("Test 18: Removing last element");
        v=new java.util.Vector();
        v.add(new Integer(1));
        v.add(new Integer(2));
        iter=new FilterIteratorTestIter(v.iterator());
        iter.next();
        iter.next();
        iter.remove();
        if(v.size()!=1)
            fail("Test 18 failed (element not removed)");
        if(iter.hasNext())
            fail("Test 18 failed (hasNext)");
        System.out.println("Test 19: Removing after hasNext");
        v=new java.util.Vector();
        v.add(new Integer(1));
        v.add(new Integer(2));
        v.add(new Integer(3));
        iter=new FilterIteratorTestIter(v.iterator());
        iter.next();
        iter.hasNext();
        try
        {
            iter.remove();
            fail("Test 19 failed: (remove after hasNext1)");
        }
        catch(IllegalStateException e)
        {
              successful++;
        }
        iter.next();
        iter.next();
        iter.hasNext();
        try
        {
            iter.remove();
            fail("Test 19 failed: (remove after hasNext2)");
        }
        catch(IllegalStateException e)
        {
            successful++;
        }
        System.out.println("\nFilterIterator successfully tested!");
    }
    
    /**
    Test the class <code>FIM.Util.FilterEnumeration</code>.
    */
    public static void EnumerationTest()
    {
        int successful=0;
        System.out.println("Testing FilterEnumeration...\n");
        java.util.Vector v;
        FilterEnumerationTestEnum enum;
        System.out.println("Test 1: No elements");
        v=new java.util.Vector();
        enum=new FilterEnumerationTestEnum(v.elements());
        if(enum.hasMoreElements())
            fail("Test 1 failed (hasMoreElements)");
        try
        {
            enum.nextElement();
            fail("Test 1 failed (nextElement)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 2: Only non-matching elements");
        v=new java.util.Vector();
        v.add(new Integer(-1));
        v.add(new Integer(-2));
        v.add(new Integer(-3));
        enum=new FilterEnumerationTestEnum(v.elements());
        if(enum.hasMoreElements())
            fail("Test 2 failed (hasMoreElements)");
        try
        {
            enum.nextElement();
            fail("Test 2 failed (nextElement)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        enum=new FilterEnumerationTestEnum(v.elements());
        try
        {
            enum.nextElement();
            fail("Test 2 failed (nextElement)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        if(enum.hasMoreElements())
            fail("Test 2 failed (hasMoreElements)");
        System.out.println("Test 3: One non-matching elements");
        v=new java.util.Vector();
        v.add(new Integer(-1));
        enum=new FilterEnumerationTestEnum(v.elements());
        if(enum.hasMoreElements())
            fail("Test 3 failed (hasMoreElements)");
        try
        {
            enum.nextElement();
            fail("Test 3 failed (nextElement)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 4: Only matching elements");
        v=new java.util.Vector();
        v.add(new Integer(1));
        v.add(new Integer(2));
        v.add(new Integer(3));
        enum=new FilterEnumerationTestEnum(v.elements());
        if(!enum.hasMoreElements())
            fail("Test 4 failed (hasMoreElements)");
        try
        {
            if(((Integer)enum.nextElement()).intValue()!=1)
                fail("Test 4 failed (wrong element)");
            if(!enum.hasMoreElements())
                fail("Test 4 failed (hasMoreElements)");
            if(((Integer)enum.nextElement()).intValue()!=2)
                fail("Test 4 failed (wrong element)");
            if(!enum.hasMoreElements())
                fail("Test 4 failed (hasMoreElements)");
            if(((Integer)enum.nextElement()).intValue()!=3)
                fail("Test 4 failed (wrong element)");
        }
        catch(Exception e)
        {
            System.out.println("Test 4 failed (nextElement)");
            System.exit(1);
        }
        if(enum.hasMoreElements())
            fail("Test 4 failed (hasMoreElements)");
        try
        {
            enum.nextElement();
            fail("Test 4 failed (nextElement)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 5: One matching elements");
        v=new java.util.Vector();
        v.add(new Integer(1));
        enum=new FilterEnumerationTestEnum(v.elements());
        if(!enum.hasMoreElements())
            fail("Test 5 failed (hasMoreElements)");
        try
        {
            if(((Integer)enum.nextElement()).intValue()!=1)
                fail("Test 5 failed (wrong element)");
        }
        catch(Exception e)
        {
            System.out.println("Test 5 failed (nextElement)");
            System.exit(1);
        }
        if(enum.hasMoreElements())
            fail("Test 5 failed (hasMoreElements)");
        try
        {
            enum.nextElement();
            fail("Test 5 failed (nextElement)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 6: First element matching");
        v=new java.util.Vector();
        v.add(new Integer(1));
        v.add(new Integer(-2));
        v.add(new Integer(-3));
        enum=new FilterEnumerationTestEnum(v.elements());
        if(!enum.hasMoreElements())
            fail("Test 6 failed (hasMoreElements)");
        try
        {
            if(((Integer)enum.nextElement()).intValue()!=1)
                fail("Test 6 failed (wrong element)");
        }
        catch(Exception e)
        {
            System.out.println("Test 6 failed (nextElement)");
            System.exit(1);
        }
        if(enum.hasMoreElements())
            fail("Test 6 failed (hasMoreElements)");
        try
        {
            enum.nextElement();
            fail("Test 6 failed (nextElement)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 7: Middle element matching");
        v=new java.util.Vector();
        v.add(new Integer(-1));
        v.add(new Integer(2));
        v.add(new Integer(-3));
        enum=new FilterEnumerationTestEnum(v.elements());
        if(!enum.hasMoreElements())
            fail("Test 7 failed (hasMoreElements)");
        try
        {
            if(((Integer)enum.nextElement()).intValue()!=2)
                fail("Test 7 failed (wrong element)");
        }
        catch(Exception e)
        {
            System.out.println("Test 7 failed (nextElement)");
            System.exit(1);
        }
        if(enum.hasMoreElements())
            fail("Test 7 failed (hasMoreElements)");
        try
        {
            enum.nextElement();
            fail("Test 7 failed (nextElement)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 8: Last element matching");
        v=new java.util.Vector();
        v.add(new Integer(-1));
        v.add(new Integer(-2));
        v.add(new Integer(3));
        enum=new FilterEnumerationTestEnum(v.elements());
        if(!enum.hasMoreElements())
            fail("Test 8 failed (hasMoreElements)");
        try
        {
            if(((Integer)enum.nextElement()).intValue()!=3)
                fail("Test 8 failed (wrong element)");
        }
        catch(Exception e)
        {
            System.out.println("Test 8 failed (nextElement)");
            System.exit(1);
        }
        if(enum.hasMoreElements())
            fail("Test 8 failed (hasMoreElements)");
        try
        {
            enum.nextElement();
            fail("Test 8 failed (nextElement)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 9: First element not matching");
        v=new java.util.Vector();
        v.add(new Integer(-1));
        v.add(new Integer(2));
        v.add(new Integer(3));
        enum=new FilterEnumerationTestEnum(v.elements());
        if(!enum.hasMoreElements())
            fail("Test 9 failed (hasMoreElements)");
        try
        {
            if(((Integer)enum.nextElement()).intValue()!=2)
                fail("Test 9 failed (wrong element)");
            if(!enum.hasMoreElements())
                fail("Test 9 failed (hasMoreElements)");
            if(((Integer)enum.nextElement()).intValue()!=3)
                fail("Test 9 failed (wrong element)");
        }
        catch(Exception e)
        {
            System.out.println("Test 9 failed (nextElement)");
            System.exit(1);
        }
        if(enum.hasMoreElements())
            fail("Test 9 failed (hasMoreElements)");
        try
        {
            enum.nextElement();
            fail("Test 9 failed (nextElement)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 10: Middle element not matching");
        v=new java.util.Vector();
        v.add(new Integer(1));
        v.add(new Integer(-2));
        v.add(new Integer(3));
        enum=new FilterEnumerationTestEnum(v.elements());
        if(!enum.hasMoreElements())
            fail("Test 10 failed (hasMoreElements)");
        try
        {
            if(((Integer)enum.nextElement()).intValue()!=1)
                fail("Test 10 failed (wrong element)");
            if(!enum.hasMoreElements())
                fail("Test 10 failed (hasMoreElements)");
            if(((Integer)enum.nextElement()).intValue()!=3)
                fail("Test 10 failed (wrong element)");
        }
        catch(Exception e)
        {
            System.out.println("Test 10 failed (nextElement)");
            System.exit(1);
        }
        if(enum.hasMoreElements())
            fail("Test 10 failed (hasMoreElements)");
        try
        {
            enum.nextElement();
            fail("Test 10 failed (nextElement)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 11: Last element not matching");
        v=new java.util.Vector();
        v.add(new Integer(1));
        v.add(new Integer(2));
        v.add(new Integer(-3));
        enum=new FilterEnumerationTestEnum(v.elements());
        if(!enum.hasMoreElements())
            fail("Test 11 failed (hasMoreElements)");
        try
        {
            if(((Integer)enum.nextElement()).intValue()!=1)
                fail("Test 11 failed (wrong element)");
            if(!enum.hasMoreElements())
                fail("Test 11 failed (hasMoreElements)");
            if(((Integer)enum.nextElement()).intValue()!=2)
                fail("Test 11 failed (wrong element)");
        }
        catch(Exception e)
        {
            System.out.println("Test 11 failed (nextElement)");
            System.exit(1);
        }
        if(enum.hasMoreElements())
            fail("Test 11 failed (hasMoreElements)");
        try
        {
            enum.nextElement();
            fail("Test 11 failed (nextElement)");
        }
        catch(NoSuchElementException e)
        {
            successful++;
        }
        System.out.println("Test 12: Setting base enumeration twice");
        v=new java.util.Vector();
        v.add(new Integer(1));
        enum=new FilterEnumerationTestEnum(v.elements());
        try
        {
            enum.setBaseEnumeration(v.elements());
            fail("Test 12 failed (base numeration set twice)");
        }
        catch(IllegalStateException e)
        {
               successful++;
        }
        System.out.println("Test 13: Base enumeration not set");
        v=new java.util.Vector();
        v.add(new Integer(1));
        enum=new FilterEnumerationTestEnum(null);
        try
        {
            enum.nextElement();
            fail("Test 13 failed (base numeration not set)");
        }
        catch(IllegalStateException e)
        {
            successful++;
        }
        try
        {
            enum.hasMoreElements();
            fail("Test 13 failed (base numeration not set)");
        }
        catch(IllegalStateException e)
        {
            successful++;
        }
        System.out.println("\nFilterEnumeration successfully tested!\n");
    }
    
    /**
    Main program for testing <code>FIM.Util.FilterEnumeration</code> and 
    <code>FIM.Util.FilterIterator</code>.
    */
    public static void main(String args[])
    {
        EnumerationTest();
        IteratorTest();
        System.exit(0);
    }

}

/**
Test class for <code>FilterIterator</code>: Returns from a list of <code>Integer</code>
objects all those larger than zero (>0).

@author  Michael Sonntag
@version 1.0, 1.7.2000
*/
class FilterIteratorTestIter extends FilterIterator
{
    public FilterIteratorTestIter(Iterator base)
    {
        if(base!=null)
            setBaseIterator(base);
    }

    protected boolean matchesFilter(Object toTest)
    {
        return ((Integer)toTest).intValue()>0;
    }
    
    public void setBaseIterator(Iterator fullEnum)
    {
        super.setBaseIterator(fullEnum);
    }
}


/**
Test class for <code>FilterEnumeration</code>: Returns from a list of <code>Integer</code>
objects all those larger than zero (>0).

@author  Michael Sonntag
@version 1.0, 1.7.2000
*/
class FilterEnumerationTestEnum extends FilterEnumeration
{
    public FilterEnumerationTestEnum(Enumeration base)
    {
        if(base!=null)
            setBaseEnumeration(base);
    }

    protected boolean matchesFilter(Object toTest)
    {
        return ((Integer)toTest).intValue()>0;
    }
    
    public void setBaseEnumeration(Enumeration fullEnum)
    {
        super.setBaseEnumeration(fullEnum);
    }
}

